@@ -1,4 +1,17 @@
-# return the coordinate in polar coordinate system in a specified cell
+# == circlize
+# Return the coordinate in polar coordinate system in a specified cell
+#
+# == param
+# -x            Data points on x-axis
+# -y            Data points on y-axis
+# -sector.index Index for the sector
+# -track.index  Index for the track
+#
+# == details
+# Return the coordinate in polar coordinate system in a specified cell
+#
+# == values
+# A matrix with two columns (``theta`` and ``rou``)
 circlize = function(x, y, sector.index = get.current.sector.index(), track.index = get.current.track.index()) {
     
     sector.data = get.sector.data(sector.index)
@@ -140,7 +153,7 @@ check.points.position = function(x, y, sector.index = NULL, track.index = NULL)
     l2 = y < cell.ylim[1] | y > cell.ylim[2]
     l = l1 | l2
     if(sum(l) && circos.par("points.overflow.warning")) {
-        warning(paste(sum(l), " point", ifelse(sum(l) == 1, " is", "s are"), " out of plotting region in sector '", sector.index, "', track '", track.index, "'.\n", sep = ""))
+        cat(paste("Note: ", sum(l), " point", ifelse(sum(l) == 1, " is", "s are"), " out of plotting region in sector '", sector.index, "', track '", track.index, "'.\n", sep = ""))
     }
 
     return(invisible(NULL))
@@ -152,4 +165,4 @@ as.radian = function(degree) {
 
 as.degree = function(radian) {
 	return(radian/pi*180)
-}
\ No newline at end of file
+}
